/*************************************************************************
 Mike Gebhard
 Agave Robotics

 Main program entry point for the AJAX/XSLT demo.

 This project simulates reading a 3 axis accelerometer and 
 displaying the results on a web page every second. 
 
 Check out the project files for more information.	
*************************************************************************/
#include "predef.h"
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <smarttrap.h>
#include <taskmon.h>
#include <NetworkDebug.h>

#include "sim5270.h"           // on-chip register definitions
#include "i2cmaster.h"          //Used for Master Only I2C
#include "xmlservices.h"			// xml I2C services
	
BYTE status;

extern "C" 
{
	void UserMain(void * pd);
}

const char * AppName="DynamicWeb"; 

void UserMain(void * pd) {
    InitializeStack();
    if (EthernetIP == 0) GetDHCPAddress();
    OSChangePrio(MAIN_PRIO);
    EnableAutoUpdate();
    StartHTTP();
    EnableTaskMonitor(); 

    #ifndef _DEBUG
    EnableSmartTraps();
    #endif

    #ifdef _DEBUG
    InitializeNetworkGDB_and_Wait();
    #endif
    
    OSTimeDly(20);
    
    
    #ifdef _I2CMASTER_H
		I2CInit();
	#endif 
	
	
	// Initailize the accelerometer
	// Acceleromoter address: 0x1D
	// Register to write to: 0x16
	// Value to write: 0x05
    status = InitializeDevice(0x1D, 0x16, 0x05); 
	
	// Write tothe debug port
    iprintf("Dynamic Web Started\r\n");
    
    while (1) {
        OSTimeDly(20);
    }
}
