/*************************************************************************
 Mike Gebhard
 Agave Robotics

 Simple I2C functions to initialize and read a 3 axis 
 I2C accelerometer.  The accel.htm page executes the
 ReadXYZ() mehtod.  The ReadXYZ() method takes 3 readings;
 x, y, and z.  The readings are sent to the requester as
 an xml fragment.  The requester in this case is an AJAX
 method in ajax.js.  The XML response is transformed to 
 XHTM by client XSLT processing. 	
*************************************************************************/
#include "predef.h" 
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <udp.h>
#include <tcp.h>
#include <string.h>
#include <ctype.h>
#include <..\MOD5270\system\sim5270.h>

#include "sim5270.h"           // on-chip register definitions
#include "i2cmaster.h"          //Used for Master Only I2C


// I2C Status
BYTE I2CStatus;

extern "C" 
{
	void ReadXYZ( int sock, PCSTR url );
	BYTE InitializeDevice( BYTE address, BYTE reg, BYTE value );
	BYTE Read_3AD(BYTE address, BYTE reg);
}


//******************************************************************
// Initialize a device on the I2C bus
//
// TODO: validate i2c status
//******************************************************************
BYTE InitializeDevice(BYTE address, BYTE reg, BYTE value) 
{
	I2CStatus = I2CStart( address, I2C_START_WRITE);
	//iprintf("I2CStart = %d \r\n", I2CStatus);
	
	I2CStatus = I2CSend(reg);
	//iprintf("I2CSend(%d) = %d \r\n", reg, I2CStatus);
	
	I2CStatus = I2CSend(value);
	//iprintf("I2CSend(%d) = %d \r\n", value, I2CStatus);
	
	I2CStop();
	//iprintf("\r\n");	
	
	return I2CStatus;   
} 
 
//***************************************
// I2C Read
//
// TODO: validate i2c status
//***************************************
BYTE Read_3AD(BYTE address, BYTE reg)
{

	BYTE Read_buffer[1]; 
    
    //clears all interupts and previous i2c conditions  
	sim.i2c.sr = 0;  
	sim.i2c.cr = 0;

	// Read Accelerometer
	I2CStatus = I2CStart( address, I2C_START_WRITE );
	I2CStatus = I2CSend( reg );
	I2CStatus = I2CRestart( address, I2C_START_READ );
	I2CStatus = I2CReadBuf(address, Read_buffer, 1);   
	I2CStatus = I2CStop();
     
    return Read_buffer[0];
}


// Send teh buffer out the socket 
void ReadXYZ( int sock, PCSTR url ) 
{
	// The defaut string is 82 characters including the %d and spaces
	// XML declarations - Not used
	// <?xml version='1.0' encoding='ISO-8859-1'?>
	// <?xml version='1.0' encoding='utf-8' ?>
	char buffer[150];
	
//	siprintf( buffer, "<accelerometer><xaxis>%d</xaxis><yaxis>%d</yaxis><zaxis>%d</zaxis></accelerometer>", 
//		Read_3AD(0x1D, 0x06), 
//		Read_3AD(0x1D, 0x07), 
//		Read_3AD(0x1D, 0x08));
		

	// Simulate sensor readings by using random numbers
  	srand (TimeTick);
  	siprintf( buffer, "<accelerometer><xaxis>%d</xaxis><yaxis>%d</yaxis><zaxis>%d</zaxis></accelerometer>", 
		 (unsigned char)(rand() & 0xFF), 
		 (unsigned char)(rand() & 0xFF), 
		 (unsigned char)(rand() & 0xFF));
		
		
	writestring( sock, buffer );
}
